# unique script for annotated first graph in article
# usage example (all on one line): gnuplot -e "grafile='noback-annotated.pdf'" basic-noback-annotated.gp

#functions

# saturation vapour pressure at temperature t
svp(t) = 610*exp(t/(t+238.3)*17.2694)

# actual vapour pressure at temperature=t and rh%=rh
vp(t,rh) = svp(t)*rh/100

# rh expected at surface with different temperature than nearby RH sensor
rhsurface(tsensor, rhsensor, tsurface) = 100.0 * mixr(tsensor,rhsensor)/mixr(tsurface,100)


w(t,rh) = log(vp(t,rh)/610.78)
dpt(t,rh) = (w(t,rh)*238.3)/(17.294-w(t,rh))
gm3(t,rh) = vp(t,rh)*2.166/(t + 273.16)

# Mixing ratio g/kg
mixr(t,rh) = (0.62 *10**(-5)*vp(t,rh))*1000 
# Expected RH with no buffer
exprh(tout,rhout,tin) = 100*vp(tout,rhout)/svp(tin)

#end of functions

set output grafile

set encoding utf8
set term pdfcairo enhanced color solid font 'Helvetica,16' size 20cm,16cm 
#set lmargin at screen 0.09
set notitle
#set title "Buffered over insulation, 18 {/Symbol \260}C average, 12 hour cycle" font "Helvetica,20"
set xdata time
set timefmt "%Y-%m-%dT%H:%M:%S"
set format x "%d/%H"
set xlabel "Day/Hour" font "Helvetica,18" 
#set xtics 3600
set xrange ["2019-07-04T12:40": "2019-07-04T20:40"]
#set xrange [starttime:stoptime]
set yrange [0:75]
set ytics 0,10,70
set mytics 2
set ylabel "Mixing Ratio (g/kg), RH (%)" font "Helvetica,18" 
#set y2range [10:47.5]
set y2range [7.5:45]
set y2label "Temperature ({/Symbol \260}C)" font "Helvetica,18"
set y2tics 15,5,35
#set key below left
set key below right height 1.5


set style rect back fs solid border lw 3 
set obj rect from graph 0,1 to graph 1,0.6 fc rgb '#e0ffee'
set obj rect from graph 0,0 to graph 1,0.22 fc rgb "#efe7ff"
set obj rect from graph 0,0.6 to graph 1,0.2 fc rgb "#ffeee0"

set label "Mixing ratios" at graph 0.05,0.08 font "Helvetica,24" textcolor rgb "#3000a0" front
set label "Temperatures" at graph 0.05,0.55 font "Helvetica,24" textcolor rgb "#a02000" front
set label "Relative humidities" at graph 0.05,0.92 font "Helvetica,24" textcolor rgb "#007020" front
set label "Room" at graph 0.6,0.5 font "Helvetica,16" front
set label "Beam" at graph 0.35,0.79 font "Helvetica,16" front
set label "Canvas" at graph 0.63,0.90 font "Helvetica,16" front
set label "Wall" at graph 0.7,0.27 font "Helvetica,16" front
set label "Beam" at graph 0.55,0.43 font "Helvetica,16" front
set label "Canvas" at graph 0.6,0.34 font "Helvetica,16" front
set label "Beam" at graph 0.36,0.18 font "Helvetica,16" front
set label "Room" at graph 0.7,0.66 font "Helvetica,16" front

set grid x front
set grid mytics front
set grid y front

set style fill transparent solid 0.5 noborder
plot "logdata-all.txt" \
using 1:7 axes x1y2 t 'T wall' with lines ls 1  \
,'' using 1:13 axes x1y2  t 'T room' with lines ls 10  \
,'' using 1:2 axes x1y2  t 'T canvas surface' with lines ls 7  \
,'' using 1:17 axes x1y2  t 'T canvas RH sensor' with lines ls 9  \
,'' using 1:17:2 axes x1y2  with filledcurves lc "pink" notitle \
,'' using 1:15 axes x1y2  t 'T beam' with lines ls 13  \
,'' using 1:14 t 'RH room' with lines ls 11  \
,'' using 1:(rhsurface($17,$18,$2))  t 'RH-c at canvas' with lines ls 17  \
,'' using 1:18  t 'RH near canvas' with lines ls 8  \
,'' using 1:(rhsurface($17,$18,$2)):18 with filledcurves lc "pink" notitle \
,'' using 1:16 t 'RH beam surface' with lines ls 14  \
,'' using 1:(mixr($13,$14)) t 'MR room' with lines ls 19  \
,'' using 1:(mixr($17,$18)) t 'MR canvas' with lines ls 18  \
,'' using 1:(mixr($15,$16)) t 'MR beam' with lines ls 20  \
